@@ -473,7 +473,7 @@ class Q2Db:
         if self.db_engine_name == "sqlite3":
             sql = sql.replace("%s", "?")
 
-        data = [record[x] for x in record.keys()]
+        data = [record[x] for x in record.keys() if x in table_columns]
 
         self._cursor(sql, data)
 
